@@ -20,7 +20,6 @@ class MockClientResponse(ClientResponse):
             continue100=None,
             timer=None,
             request_info=None,
-            auto_decompress=None,
             traces=None,
             loop=asyncio.get_event_loop(),
             session=None,
@@ -28,16 +27,16 @@ class MockClientResponse(ClientResponse):
 
     # TODO: get encoding from header
     @asyncio.coroutine
-    def json(self, *, encoding='utf-8', loads=json.loads):  # NOQA: E999
-        return loads(self.content.decode(encoding))
+    def json(self, *, encoding='utf-8', loads=json.loads, **kwargs):  # NOQA: E999
+        return loads(self._body.decode(encoding))
 
     @asyncio.coroutine
     def text(self, encoding='utf-8'):
-        return self.content.decode(encoding)
+        return self._body.decode(encoding)
 
     @asyncio.coroutine
     def read(self):
-        return self.content
+        return self._body
 
     @asyncio.coroutine
     def release(self):
@@ -52,11 +51,13 @@ def vcr_request(cassette, real_request):
         headers = self._prepare_headers(headers)
         data = kwargs.get('data')
         params = kwargs.get('params')
+
+        request_url = URL(url)
         if params:
             for k, v in params.items():
                 params[k] = str(v)
+            request_url = URL(url).with_query(params)
 
-        request_url = URL(url).with_query(params)
         vcr_request = Request(method, str(request_url), data, headers)
 
         if cassette.can_play_response_for(vcr_request):
@@ -64,9 +65,9 @@ def vcr_request(cassette, real_request):
 
             response = MockClientResponse(method, URL(vcr_response.get('url')))
             response.status = vcr_response['status']['code']
-            response.content = vcr_response['body']['string']
+            response._body = vcr_response['body']['string']
             response.reason = vcr_response['status']['message']
-            response.headers = vcr_response['headers']
+            response._headers = vcr_response['headers']
 
             response.close()
             return response
@@ -77,7 +78,7 @@ def vcr_request(cassette, real_request):
             msg = ("No match for the request {!r} was found. Can't overwrite "
                    "existing cassette {!r} in your current record mode {!r}.")
             msg = msg.format(vcr_request, cassette._path, cassette.record_mode)
-            response.content = msg.encode()
+            response._body = msg.encode()
             response.close()
             return response
 
